'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _characters = require('../../database/characters');

var _characters2 = _interopRequireDefault(_characters);

var _config = require('../../config');

var _config2 = _interopRequireDefault(_config);

var _pagination = require('../../util/pagination');

var _pagination2 = _interopRequireDefault(_pagination);

var _commandUsage = require('../../util/command-usage');

var usage = _interopRequireWildcard(_commandUsage);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
	name: 'characters',
	aliases: ['listcharacters', 'listchars', 'chars'],
	group: 'characters',
	groupName: 'list',
	description: 'Lists/searches characters in the database.',
	usage: 'characters [search] [page]',
	details: 'If no search string is specified, all characters will be listed. If the search string is only one letter long, characters that start with that character will be listed. If the search string is more than one letter, all characters that contain that string will be listed. If the search string contains spaces, it must be surrounded by quotes.',
	examples: ['characters', 'characters c', 'characters bill'],

	isRunnable(message) {
		return !!message.server;
	},

	run(message, args) {
		const search = args.length >= 2 || isNaN(args[0]) ? args[0] : '';
		const page = args.length >= 2 ? parseInt(args[1]) : !isNaN(args[0]) ? parseInt(args[0]) : 1;
		let characters = _characters2.default.findCharactersInServer(message.server, search, false);
		if (characters.length > 0) {
			characters.sort((a, b) => a.name < b.name ? -1 : a.name > b.name ? 1 : 0);
			const paginated = (0, _pagination2.default)(characters, page, Math.floor(_config2.default.paginationItems));
			characters = paginated.items;

			let messageText = search ? (search.length === 1 ? 'Characters that begin with' : 'Characters that contain') + ' "' + search + '"' : 'Character list';
			messageText += ', ' + paginated.pageText + ' (Use ';
			if (paginated.maxPage > 1) messageText += usage.short('characters' + (search ? ' ' + search : '') + ' <page>') + ' to view a specific page, or ';
			messageText += usage.short('character <name>') + ' to view information about a character):';
			messageText += '\n\n' + characters.map(element => element.name).join('\n');
			message.client.reply(message, messageText);
		} else {
			const messageText = 'There are no characters ' + (search ? (search.length === 1 ? 'that begin with' : 'that contain') + ' "' + search + '".' : 'in the database.');
			message.client.reply(message, messageText);
		}
	}
};