'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _rpbot = require('../../rpbot');

var _config = require('../../config');

var _config2 = _interopRequireDefault(_config);

var _commandPattern = require('../../util/command-pattern');

var _commandPattern2 = _interopRequireDefault(_commandPattern);

var _permissions = require('../../util/permissions');

var permissions = _interopRequireWildcard(_permissions);

var _commandUsage = require('../../util/command-usage');

var usage = _interopRequireWildcard(_commandUsage);

var _settings = require('../../database/settings');

var _settings2 = _interopRequireDefault(_settings);

var _setting = require('../../database/setting');

var _setting2 = _interopRequireDefault(_setting);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
	name: 'prefix',
	group: 'general',
	groupName: 'prefix',
	description: 'Shows or sets the command prefix.',
	usage: 'prefix [prefix|"default"|"none"]',
	details: 'If no prefix is provided, the current prefix will be shown. If the prefix is "default", the prefix will be reset to the bot\'s default prefix. If the prefix is "none", the prefix will be removed entirely, only allowing mentions to run commands. Only administrators may change the prefix.',
	examples: ['prefix', 'prefix -', 'prefix rp!', 'prefix default', 'prefix none'],
	singleArgument: true,

	isRunnable() {
		return true;
	},

	run(message, args) {
		if (args[0] && message.server) {
			// Only allow administrators
			if (!permissions.isAdministrator(message.server, message.author)) {
				message.client.reply(message, 'Only administrators may change the command prefix.');
				return;
			}

			// Save the prefix
			const lowercase = args[0].toLowerCase();
			const prefix = lowercase === 'none' ? '' : args[0];
			let response;
			if (lowercase === 'default') {
				_settings2.default.deleteSetting('command-prefix', message.server);
				response = `Reset the command prefix to default (currently "${ _config2.default.commandPrefix }").`;
			} else {
				_settings2.default.saveSetting(new _setting2.default(message.server, 'command-prefix', prefix));
				response = prefix ? `Set the command prefix to "${ args[0] }".` : 'Removed the command prefix entirely.';
			}

			// Build the pattern
			const pattern = (0, _commandPattern2.default)(message.server, _rpbot.client.user);
			_rpbot.serverCommandPatterns[message.server.id] = pattern;

			message.client.reply(message, `${ response } To run commands, use ${ usage.long('command', message.server) }.`);
		} else {
			const prefix = message.server ? _settings2.default.getSettingValue('command-prefix', _config2.default.commandPrefix, message.server) : _config2.default.commandPrefix;
			const response = prefix ? `The command prefix is "${ prefix }".` : 'There is no command prefix.';
			message.client.reply(message, response + ` To run commands, use ${ usage.long('command', message.server) }`);
		}
	}
};