'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _character = require('./character');

var _character2 = _interopRequireDefault(_character);

var _localStorage = require('./local-storage');

var _localStorage2 = _interopRequireDefault(_localStorage);

var _search = require('../util/search');

var _search2 = _interopRequireDefault(_search);

var _logger = require('../util/logger');

var _logger2 = _interopRequireDefault(_logger);

var _permissions = require('../util/permissions');

var permissions = _interopRequireWildcard(_permissions);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class CharacterDatabase {
	static loadDatabase() {
		this.serversMap = JSON.parse(_localStorage2.default.getItem('characters'));
		if (!this.serversMap) this.serversMap = {};
	}

	static saveDatabase() {
		_logger2.default.debug('Saving characters database...', this.serversMap);
		_localStorage2.default.setItem('characters', JSON.stringify(this.serversMap));
	}

	static saveCharacter(character) {
		if (!character) throw new Error('A character must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[character.server]) this.serversMap[character.server] = [];
		const serverCharacters = this.serversMap[character.server];

		const normalizedName = character.name.normalize('NFKD').toLowerCase();
		const characterIndex = serverCharacters.findIndex(element => element.name.normalize('NFKD').toLowerCase() === normalizedName);
		if (characterIndex >= 0) {
			if (character.owner === serverCharacters[characterIndex].owner || permissions.isModerator(character.server, character.owner)) {
				character.owner = serverCharacters[characterIndex].owner;
				serverCharacters[characterIndex] = character;
				_logger2.default.info('Updated existing character.', character);
				this.saveDatabase();
				return 2;
			} else {
				_logger2.default.info('Not updating existing character, because the owner isn\'t the original owner.', { character: character, original: serverCharacters[characterIndex] });
				return 0;
			}
		} else {
			serverCharacters.push(character);
			_logger2.default.info('Added new character.', character);
			this.saveDatabase();
			return 1;
		}
	}

	static deleteCharacter(character) {
		if (!character) throw new Error('A character must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[character.server]) return false;
		const serverCharacters = this.serversMap[character.server];

		const characterIndex = serverCharacters.findIndex(element => element.name === character.name);
		if (characterIndex >= 0) {
			if (character.owner === serverCharacters[characterIndex].owner || permissions.isModerator(character.server, character.owner)) {
				serverCharacters.splice(characterIndex, 1);
				_logger2.default.info('Removed character.', character);
			} else {
				_logger2.default.info('Not removing character, because the owner isn\'t the original owner.', { character: character, original: serverCharacters[characterIndex] });
				return false;
			}
		} else {
			_logger2.default.info('Not removing character, because it doesn\'t exist.', character);
			return false;
		}

		this.saveDatabase();
		return true;
	}

	static findCharactersInServer(server, searchString = null, searchExact = true) {
		if (!server) throw new Error('A server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[server.id]) return [];

		const characters = (0, _search2.default)(this.serversMap[server.id], searchString, { useStartsWith: true, searchExact: searchExact });

		// Make sure they're all Character instances
		for (const [index, character] of characters.entries()) {
			if (!(character instanceof _character2.default)) characters[index] = new _character2.default(character.server, character.owner, character.name, character.info);
		}

		return characters;
	}
}
exports.default = CharacterDatabase;