'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _localStorage = require('./local-storage');

var _localStorage2 = _interopRequireDefault(_localStorage);

var _search = require('../util/search');

var _search2 = _interopRequireDefault(_search);

var _logger = require('../util/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ModRolesDatabase {
	static loadDatabase() {
		this.serversMap = JSON.parse(_localStorage2.default.getItem('mod-roles'));
		if (!this.serversMap) this.serversMap = {};
	}

	static saveDatabase() {
		_logger2.default.debug('Saving mod roles database...', this.serversMap);
		_localStorage2.default.setItem('mod-roles', JSON.stringify(this.serversMap));
	}

	static saveRole(role) {
		if (!role) throw new Error('A role must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[role.server.id]) this.serversMap[role.server.id] = [];
		const serverRoles = this.serversMap[role.server.id];

		if (!serverRoles.includes(role.id)) {
			serverRoles.push(role.id);
			_logger2.default.info('Added new mod role.', this.basicRoleInfo(role));
			this.saveDatabase();
			return true;
		} else {
			_logger2.default.info('Not adding mod role, because it already exists.', this.basicRoleInfo(role));
			return false;
		}
	}

	static deleteRole(role) {
		if (!role) throw new Error('A role must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[role.server.id]) return false;
		const serverRoles = this.serversMap[role.server.id];

		const roleIndex = serverRoles.findIndex(element => element === role.id);
		if (roleIndex >= 0) {
			serverRoles.splice(roleIndex, 1);
			_logger2.default.info('Removed mod role.', this.basicRoleInfo(role));
			this.saveDatabase();
			return true;
		} else {
			_logger2.default.info('Not removing mod role, because it doesn\'t exist.', this.basicRoleInfo(role));
			return false;
		}
	}

	static findRolesInServer(server, searchString = null) {
		if (!server) throw new Error('A server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[server.id]) return [];

		// Find all of the server's roles that match, and filter them to ones that are mod roles
		const roles = (0, _search2.default)(server.roles, searchString, { searchExact: false }).filter(r => this.serversMap[server.id].includes(r.id));
		return (0, _search2.default)(roles, searchString, { searchInexact: false });
	}

	static serverHasRoles(server) {
		if (!server) throw new Error('A server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		return this.serversMap[server.id] && this.serversMap[server.id].length > 0;
	}

	static basicRoleInfo(role) {
		return { id: role.id, name: role.name, server: role.server.name, serverID: role.server.id };
	}
}
exports.default = ModRolesDatabase;