'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _setting = require('./setting');

var _setting2 = _interopRequireDefault(_setting);

var _localStorage = require('./local-storage');

var _localStorage2 = _interopRequireDefault(_localStorage);

var _logger = require('../util/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class SettingsDatabase {
	static loadDatabase() {
		this.serversMap = JSON.parse(_localStorage2.default.getItem('settings'));
		if (!this.serversMap) this.serversMap = {};
	}

	static saveDatabase() {
		_logger2.default.debug('Saving settings database...', this.serversMap);
		_localStorage2.default.setItem('settings', JSON.stringify(this.serversMap));
	}

	static saveSetting(setting) {
		if (!setting) throw new Error('A setting must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!this.serversMap[setting.server]) this.serversMap[setting.server] = {};
		this.serversMap[setting.server][setting.key] = setting.value;
		_logger2.default.info('Saved setting.', setting);
		this.saveDatabase();
		return true;
	}

	static getSetting(setting, server = null) {
		if (!(setting instanceof _setting2.default) && (!setting || !server)) throw new Error('A setting or a key and server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!server) server = setting.server;
		if (server.id) server = server.id;
		if (!this.serversMap[server]) return null;
		const key = setting instanceof _setting2.default ? setting.key : setting;
		return new _setting2.default(server, key, this.serversMap[server][key]);
	}

	static getSettingValue(setting, defaultValue = null, server = null) {
		if (!(setting instanceof _setting2.default) && (!setting || !server)) throw new Error('A setting or a key and server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!server) server = setting.server;
		if (server.id) server = server.id;
		if (!this.serversMap[server]) return defaultValue;
		const key = setting instanceof _setting2.default ? setting.key : setting;
		return typeof this.serversMap[server][key] !== 'undefined' ? this.serversMap[server][key] : defaultValue;
	}

	static deleteSetting(setting, server = null) {
		if (!(setting instanceof _setting2.default) && (!setting || !server)) throw new Error('A setting or a key and server must be specified.');
		if (!this.serversMap) this.loadDatabase();
		if (!server) server = setting.server;
		if (server.id) server = server.id;
		if (!this.serversMap[server]) return false;
		const key = setting instanceof _setting2.default ? setting.key : setting;
		if (typeof this.serversMap[server][key] === 'undefined') return false;
		delete this.serversMap[server][key];
		_logger2.default.info('Removed setting.', { key: key, server: server });
		this.saveDatabase();
		return true;
	}
}
exports.default = SettingsDatabase;