#!/usr/bin/env node

'use babel';
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.serverCommandPatterns = exports.client = undefined;

var _discord = require('discord.js');

var _discord2 = _interopRequireDefault(_discord);

var _stringArgv = require('string-argv');

var _stringArgv2 = _interopRequireDefault(_stringArgv);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _version = require('./version');

var _version2 = _interopRequireDefault(_version);

var _commands = require('./commands');

var _commands2 = _interopRequireDefault(_commands);

var _logger = require('./util/logger');

var _logger2 = _interopRequireDefault(_logger);

var _commandPattern = require('./util/command-pattern');

var _commandPattern2 = _interopRequireDefault(_commandPattern);

var _updateCheck = require('./util/update-check');

var _updateCheck2 = _interopRequireDefault(_updateCheck);

var _commandUsage = require('./util/command-usage');

var usage = _interopRequireWildcard(_commandUsage);

var _analytics = require('./util/analytics');

var analytics = _interopRequireWildcard(_analytics);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_logger2.default.info('RPBot v' + _version2.default + ' is starting...');
analytics.sendEvent('Bot', 'started');

// Output safe config
const debugConfig = Object.assign({}, _config2.default);
if (debugConfig.email) debugConfig.email = '--snip--';
if (debugConfig.password) debugConfig.password = '--snip--';
if (debugConfig.token) debugConfig.token = '--snip--';
for (const key of Object.keys(debugConfig)) if (key.length === 1 || key.includes('-')) delete debugConfig[key];
_logger2.default.debug('Configuration:', debugConfig);

// Verify that the credentials are usable
if (!_config2.default.token && (!_config2.default.email || !_config2.default.password)) {
	_logger2.default.error('Invalid credentials; either "token" or both "email" and "password" must be specified.');
	process.exit(1);
}

// Create client
const clientOptions = { autoReconnect: _config2.default.autoReconnect, forceFetchUsers: true, disableEveryone: true };
const client = exports.client = new _discord2.default.Client(clientOptions);
_logger2.default.info('Client created.', clientOptions);
client.on('error', e => {
	_logger2.default.error(e);
});
client.on('warn', e => {
	_logger2.default.warn(e);
});
client.on('debug', e => {
	_logger2.default.debug(e);
});
client.on('disconnected', () => {
	_logger2.default.error('Disconnected.');
});
client.on('ready', () => {
	_logger2.default.info(`Bot is ready; logged in as ${ client.user.username }#${ client.user.discriminator } (ID: ${ client.user.id })`);
	(0, _updateCheck2.default)();
	if (_config2.default.updateCheck > 0) setInterval(_updateCheck2.default, _config2.default.updateCheck * 60 * 1000);
});

// Set up command recognition
const serverCommandPatterns = exports.serverCommandPatterns = {};
client.on('message', message => {
	if (message.author === client.user) return;
	let runCommand;
	let runArgs;
	let runFromPattern = false;

	// Find the command to run by patterns
	commandLoop: for (const command of _commands2.default) {
		if (!command.patterns) continue;
		for (const pattern of command.patterns) {
			const matches = pattern.exec(message.content);
			if (matches) {
				runCommand = command;
				runArgs = matches;
				runFromPattern = true;
				break commandLoop;
			}
		}
	}

	// Find the command to run with default command handling
	const patternIndex = message.server ? message.server.id : '-';
	if (!serverCommandPatterns[patternIndex]) serverCommandPatterns[patternIndex] = (0, _commandPattern2.default)(message.server, client.user);
	let defaultMatches;
	if (!runCommand) {
		defaultMatches = serverCommandPatterns[patternIndex].exec(message.content);
		if (defaultMatches) {
			const commandName = defaultMatches[2].toLowerCase();
			const command = _commands2.default.find(command => command.name === commandName || command.aliases && command.aliases.some(alias => alias === commandName));
			if (command && !command.disableDefault) {
				const argString = message.content.substring(defaultMatches[1].length + defaultMatches[2].length);
				runCommand = command;
				runArgs = !command.singleArgument ? (0, _stringArgv2.default)(argString) : [argString.trim()];
			}
		}
	}

	// Run the command
	if (runCommand) {
		const logInfo = {
			args: runArgs.toString(),
			user: message.author.username + '#' + message.author.discriminator,
			userID: message.author.id,
			server: message.server ? message.server.name : null,
			serverID: message.server ? message.server.id : null
		};

		if (runCommand.isRunnable(message)) {
			_logger2.default.info(`Running ${ runCommand.group }:${ runCommand.groupName }.`, logInfo);
			analytics.sendEvent('Command', 'run', runCommand.group + ':' + runCommand.groupName);
			try {
				const result = runCommand.run(message, runArgs, runFromPattern);
				if (typeof result !== 'undefined' && !result) client.reply(message, `Invalid command format. Use \`!help ${ runCommand.name }\` for information.`);
			} catch (e) {
				client.reply(message, `An error occurred while running the command. (${ e.name }: ${ e.message })`);
				_logger2.default.error(e);
				analytics.sendException(e);
			}
		} else {
			_logger2.default.info(`Not running ${ runCommand.group }:${ runCommand.groupName }; not runnable.`, logInfo);
		}
	} else if (defaultMatches) {
		if (!_config2.default.unknownOnlyMention || defaultMatches[1].startsWith('<@')) client.reply(message, `Unknown command. Use ${ usage.long('help', message.server) } to view the list of all commands.`);
	}
});

// Log in
const loginCallback = e => {
	if (e) _logger2.default.error('Failed to login.', e);
};
if (_config2.default.token) {
	_logger2.default.info('Logging in with token...');
	client.loginWithToken(_config2.default.token, _config2.default.email, _config2.default.password, loginCallback);
} else {
	_logger2.default.info('Logging in with email and password...');
	client.login(_config2.default.email, _config2.default.password, loginCallback);
}

// Exit on interrupt
process.on('SIGINT', () => {
	_logger2.default.info('Received interrupt signal; destroying client and exiting...');
	client.destroy(() => {
		process.exit(0);
	});
});